<?php

require_once("include_main.php");

function check_disk_space() {
    $limit = 90;
    if(isset($_GET["limit"])) $limit = intval($_GET["limit"]);
    $info = MainMethods::getDiskInfo();
    if($info[MainMethods::diskUsePercent] >= $limit) {
        $msg = $info[MainMethods::diskUsePercent].
                "% of your main partition are full (size: ".
                $info[MainMethods::diskSize].", used: ".
                $info[MainMethods::diskUsed].", available: ".
                $info[MainMethods::diskAvailable].")";
        send_alarm("Disk nearly full", $msg, Alarms::alDiskFull);
    }
    else {
        clear_alarm(Alarms::alDiskFull);
    }
}

function generateRandomString($length = 10) {
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, $charactersLength - 1)];
    }
    return $randomString;
}

function check_read_only() {
    $writeContent = generateRandomString();         // we use a random string in case the file can't be deleted and already exists
    $testFile = Config::webRoot."/innovaphone.check.pid";
    @unlink($testFile);
    $triggerAlarm = false;
    if(file_exists($testFile)) {
        $triggerAlarm = true;
    }
    else {
        file_put_contents($testFile, $writeContent);
        $content = file_get_contents($testFile);
        if($content != $writeContent) {
            $triggerAlarm = true;
        }
    }
    @unlink($testFile);
    if($triggerAlarm) {
        send_alarm("Read-only partition", "The linux partition has been mounted read-only. Try to boot from the ram disk and run e2fsck. Your hard drive might be defect or its file system corrupted!", Alarms::alDiskReadOnly);
    }
    else {
        clear_alarm(Alarms::alDiskReadOnly);
    }
}

function check_bad_blocks()
{
    if(runs_in_vm()) return;        // badblocks doesn't make sense for VMs, as physical drives are logically mapped
    $hour = intval(date("H"));
    $min = intval(date("i"));
    if($hour == 0 && $min < 30) {   // just run once between 00:00 and 00:30 (check.php is called every 30 minutes)
        $ret = 0;
        $out = main_system("badblocks -v /dev/sda 2>&1", $ret);
        if(strpos($out, "(0/0/0 errors)") === false) {
            $msg = "Bad blocks have been found on your CF card. It might be defect and its file system corrupted! Output of badblocks: ".$out;
            send_alarm("Bad blocks found", $msg, Alarms::alDiskBadBlocks);
        }
        else {
            clear_alarm(Alarms::alDiskBadBlocks);
        }
    }
}

function check() {
    check_disk_space();
    check_read_only();
    check_bad_blocks();
}

check();
global $mainSession;
$mainSession->destroy();
?>